summaryrefslogtreecommitdiff
path: root/Debian/Debhelper/Dh_Lib.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Debian/Debhelper/Dh_Lib.pm')
-rw-r--r--Debian/Debhelper/Dh_Lib.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/Debian/Debhelper/Dh_Lib.pm b/Debian/Debhelper/Dh_Lib.pm
index 92eae0c7..4beaa0dc 100644
--- a/Debian/Debhelper/Dh_Lib.pm
+++ b/Debian/Debhelper/Dh_Lib.pm
@@ -209,7 +209,7 @@ sub dirname {
return $fn;
}
# Pass in a number, will return true iff the current compatability level
# is less than or equal to that number.
sub compat {
my $num=shift;
@@ -220,7 +220,7 @@ sub compat {
}
if ($c > $max_compat) {
- error("Sorry, but $max_compat is the highest compatability level of debhelper currently supported.");
+ error("Sorry, but $max_compat is the highest compatibility level of debhelper currently supported.");
}
return ($c <= $num);
@@ -235,7 +235,7 @@ sub tmpdir {
return $dh{TMPDIR};
}
elsif (compat(1) && $package eq $dh{MAINPACKAGE}) {
# This is for back-compatability with the debian/tmp tradition.
return "debian/tmp";
}
else {
@@ -209,7 +209,7 @@ sub dirname {
return $fn;
}
-# Pass in a number, will return true iff the current compatability level
+# Pass in a number, will return true iff the current compatibility level
# is less than or equal to that number.
sub compat {
@@ -235,7 +235,7 @@ sub tmpdir {
}
elsif (compat(1) && $package eq $dh{MAINPACKAGE}) {
- # This is for back-compatability with the debian/tmp tradition.
+ # This is for back-compatibility with the debian/tmp tradition.
return "debian/tmp";
}